@@ -190,13 +190,14 @@ class PgAclAddCommand(_AclAddHelper):
 
 class _AclDelHelper(cmd.BaseCommand):
     def __init__(self, api, entity, direction=None,
-                 priority=None, match=None):
+                 priority=None, match=None, if_exists=False):
         if (priority is None) != (match is None):
             raise TypeError("Must specify priority and match together")
         if priority is not None and not direction:
             raise TypeError("Cannot specify priority/match without direction")
         super().__init__(api)
         self.entity = entity
+        self.if_exists = if_exists
         self.conditions = []
         if direction:
             self.conditions.append(('direction', '=', direction))
@@ -206,7 +207,14 @@ class _AclDelHelper(cmd.BaseCommand):
                                     ('match', '=', match)]
 
     def run_idl(self, txn):
-        entity = self.api.lookup(self.lookup_table, self.entity)
+        try:
+            entity = self.api.lookup(self.lookup_table, self.entity)
+        except idlutils.RowNotFound as e:
+            if self.if_exists:
+                return
+            msg = "%s %s does not exist" % (self.lookup_table, self.entity)
+            raise RuntimeError(msg) from e
+
         for acl in [a for a in entity.acls
                     if idlutils.row_match(a, self.conditions)]:
             entity.delvalue('acls', acl)
@@ -216,12 +224,6 @@ class _AclDelHelper(cmd.BaseCommand):
 class AclDelCommand(_AclDelHelper):
     lookup_table = 'Logical_Switch'
 
-    def __init__(self, api, switch, direction=None,
-                 priority=None, match=None):
-        # NOTE: we're overriding the constructor here to not break any
-        # existing callers before we introduced Port Groups.
-        super().__init__(api, switch, direction, priority, match)
-
 
 class PgAclDelCommand(_AclDelHelper):
     lookup_table = 'Port_Group'
@@ -1223,7 +1225,7 @@ class LspAttachMirror(cmd.BaseCommand):
                 msg = "Mirror Rule %s is already set on LSP %s" % (self.mirror,
                                                                    self.port)
                 raise RuntimeError(msg)
-            lsp.addvalue('mirror_rules', self.mirror)
+            lsp.addvalue('mirror_rules', mirror)
         except idlutils.RowNotFound as e:
             raise RuntimeError("LSP %s not found" % self.port) from e
 
@@ -1243,7 +1245,7 @@ class LspDetachMirror(cmd.BaseCommand):
                 msg = "Mirror Rule %s doesn't exist on LSP %s" % (self.mirror,
                                                                   self.port)
                 raise RuntimeError(msg)
-            lsp.delvalue('mirror_rules', self.mirror)
+            lsp.delvalue('mirror_rules', mirror)
         except idlutils.RowNotFound as e:
             if self.if_exists:
                 return
@@ -1670,15 +1672,22 @@ class LbDelHealthCheckCommand(cmd.BaseCommand):
             raise RuntimeError(msg)
 
 
-class LbAddIpPortMappingCommand(cmd.BaseCommand):
+class LbIpPortMappingCommand(cmd.BaseCommand):
+    @staticmethod
+    def normalize_ip(ip_str):
+        ip = netaddr.IPAddress(ip_str)
+        return f"[{ip}]" if ip.version == 6 else str(ip)
+
+
+class LbAddIpPortMappingCommand(LbIpPortMappingCommand):
     table = 'Load_Balancer'
 
     def __init__(self, api, lb, endpoint_ip, port_name, source_ip):
         super().__init__(api)
         self.lb = lb
-        self.endpoint_ip = str(netaddr.IPAddress(endpoint_ip))
+        self.endpoint_ip = self.normalize_ip(endpoint_ip)
         self.port_name = port_name
-        self.source_ip = str(netaddr.IPAddress(source_ip))
+        self.source_ip = self.normalize_ip(source_ip)
 
     def run_idl(self, txn):
         lb = self.api.lookup(self.table, self.lb)
@@ -1686,13 +1695,13 @@ class LbAddIpPortMappingCommand(cmd.BaseCommand):
                   '%s:%s' % (self.port_name, self.source_ip))
 
 
-class LbDelIpPortMappingCommand(cmd.BaseCommand):
+class LbDelIpPortMappingCommand(LbIpPortMappingCommand):
     table = 'Load_Balancer'
 
     def __init__(self, api, lb, endpoint_ip):
         super().__init__(api)
         self.lb = lb
-        self.endpoint_ip = str(netaddr.IPAddress(endpoint_ip))
+        self.endpoint_ip = self.normalize_ip(endpoint_ip)
 
     def run_idl(self, txn):
         lb = self.api.lookup(self.table, self.lb)
